@@ -263,9 +263,7 @@ NetworkModelItem::ItemType NetworkModelItem::itemType() const
 #if NM_CHECK_VERSION(0, 9, 10)
         m_type == NetworkManager::ConnectionSettings::Team ||
 #endif
-        ((NetworkManager::status() == NetworkManager::Connected ||
-          NetworkManager::status() == NetworkManager::ConnectedLinkLocal ||
-          NetworkManager::status() == NetworkManager::ConnectedSiteOnly) && m_type == NetworkManager::ConnectionSettings::Vpn)) {
+        (NetworkManager::status() == NetworkManager::Connected && m_type == NetworkManager::ConnectionSettings::Vpn)) {
         if (m_connectionPath.isEmpty() && m_type == NetworkManager::ConnectionSettings::Wireless) {
             return NetworkModelItem::AvailableAccessPoint;
         } else if (m_connectionPath.isEmpty() && m_type == NetworkManager::ConnectionSettings::Wimax) {
